==> samigo-services-10.7-sources.jar: org/sakaiproject/tool/assessment/services/shared/MediaService.java <==
/**********************************************************************************
 * $URL: https://source.sakaiproject.org/svn/sam/tags/sakai-10.7/samigo-services/src/java/org/sakaiproject/tool/assessment/services/shared/MediaService.java $
 * $Id: MediaService.java 319083 2015-05-20 22:24:13Z enietzel@anisakai.com $
 ***********************************************************************************
 *
 * Copyright (c) 2004, 2005, 2006, 2008 The Sakai Foundation
 *
 * Licensed under the Educational Community License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.opensource.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 **********************************************************************************/


package org.sakaiproject.tool.assessment.services.shared;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.sakaiproject.tool.assessment.services.PersistenceService;


/**
 * The QuestionPoolService calls the service locator to reach the
 * manager on the back end.
 * @author Rachel Gollub <rgollub@stanford.edu>
 */
public class MediaService
{
  private Log log = LogFactory.getLog(MediaService.class);

  /**
   * Creates a new QuestionPoolService object.
   */
  public MediaService()  {
  }

  public void remove(String mediaId)
  {
     PersistenceService.getInstance().getAssessmentGradingFacadeQueries().
       removeMediaById(new Long(mediaId));
  }
  
  public void remove(String mediaId, Long itemGradingId)
  {
     PersistenceService.getInstance().getAssessmentGradingFacadeQueries().
       removeMediaById(new Long(mediaId), itemGradingId);
  }

}

==> samigo-services-11.2-sources.jar: org/sakaiproject/tool/assessment/services/shared/MediaService.java <==
/**********************************************************************************
 * $URL$
 * $Id$
 ***********************************************************************************
 *
 * Copyright (c) 2004, 2005, 2006, 2008 The Sakai Foundation
 *
 * Licensed under the Educational Community License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.opensource.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 **********************************************************************************/


package org.sakaiproject.tool.assessment.services.shared;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.sakaiproject.tool.assessment.services.PersistenceService;


/**
 * The QuestionPoolService calls the service locator to reach the
 * manager on the back end.
 * @author Rachel Gollub <rgollub@stanford.edu>
 */
public class MediaService
{
  private Logger log = LoggerFactory.getLogger(MediaService.class);

  /**
   * Creates a new QuestionPoolService object.
   */
  public MediaService()  {
  }

  public void remove(String mediaId)
  {
     PersistenceService.getInstance().getAssessmentGradingFacadeQueries().
       removeMediaById(new Long(mediaId));
  }
  
  public void remove(String mediaId, Long itemGradingId)
  {
     PersistenceService.getInstance().getAssessmentGradingFacadeQueries().
       removeMediaById(new Long(mediaId), itemGradingId);
  }

}
